@@ -29,6 +29,7 @@ from ckms.types import KeyUseType
 from ckms.types import Signer
 from ckms.types import Verifier
 from .basekeyspecification import BaseKeySpecification
+from .certificate import Certificate
 from .publickeyspecification import PublicKeySpecification
 
 
@@ -46,6 +47,7 @@ class KeySpecification(BaseKeySpecification, Decrypter, Encrypter, Signer, Verif
     loaded: bool = False
     tags: set[str] = set()
     key_ops: set[KeyOperationType] = set()
+    certificate: Certificate | None
 
     @pydantic.root_validator(allow_reuse=True, pre=True)
     def _autodiscover(cls, values: dict[str, Any]) -> dict[str, Any]:
@@ -87,6 +89,8 @@ class KeySpecification(BaseKeySpecification, Decrypter, Encrypter, Signer, Verif
                 self.key_ops.add(KeyOperationType.sign)
                 if self.is_symmetric():
                     self.key_ops.add(KeyOperationType.verify)
+        if self.certificate is not None:
+            await self.certificate.load()
         return self
 
     async def load(self) -> 'KeySpecification':
@@ -125,7 +129,14 @@ class KeySpecification(BaseKeySpecification, Decrypter, Encrypter, Signer, Verif
                 "Symmetric keys do not have a public key. Set `private=True` "
                 "to project the private key to a JSON Web Key (JWK)."
             )
-        return self.provider.jwk(self, private=private)
+        claims: dict[str, Any] = {}
+        if self.certificate:
+            claims.update(self.certificate.claims())
+        return self.provider.jwk(
+            spec=self,
+            private=private,
+            **claims
+        )
 
     def can_encrypt(self) -> bool:
         return self.can_perform(KeyOperationType.encrypt)
