@@ -12,14 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from .algorithmidentifier import AlgorithmIdentifier
-from .messageimprint import MessageImprint
-from .timestamprequest import TimestampRequest
-from .timestampresponse import TimestampResponse
+from .pkifailureinfo import PKIFailureInfo
+from .pkistatus import PKIStatus
+from .pkistatusinfo import PKIStatusInfo
+from .timestamp import Timestamp
+from .timestampresp import TimeStampResp
 
 
 __all__: list[str] = [
     'AlgorithmIdentifier',
-    'MessageImprint',
-    'TimestampRequest',
-    'TimestampResponse',
+    'PKIFailureInfo',
+    'PKIStatus',
+    'PKIStatusInfo',
+    'Timestamp',
+    'TimeStampResp',
 ]
\ No newline at end of file
